==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Shape_detection/group__PkgShapeDetectionRANSACShapes.js <==
var group__PkgShapeDetectionRANSACShapes =
[
    [ "Cone", "classCGAL_1_1Shape__detection_1_1Cone.html", [
      [ "Cone", "classCGAL_1_1Shape__detection_1_1Cone.html#a57ad4c0d0d80c6f228d850ce304dbe88", null ],
      [ "angle", "classCGAL_1_1Shape__detection_1_1Cone.html#a91e85e725e1f29a25124a79bfe832006", null ],
      [ "apex", "classCGAL_1_1Shape__detection_1_1Cone.html#ae3a791836bfb4045ff156bd528c288fa", null ],
      [ "axis", "classCGAL_1_1Shape__detection_1_1Cone.html#ada8393051c8779eb9360007c6e69ad55", null ]
    ] ],
    [ "Cylinder", "classCGAL_1_1Shape__detection_1_1Cylinder.html", [
      [ "Line_3", "classCGAL_1_1Shape__detection_1_1Cylinder.html#a5ec92e1e403f53f2ff78618b73a5698d", null ],
      [ "Cylinder", "classCGAL_1_1Shape__detection_1_1Cylinder.html#a0dbb8aadecc54ee734ceb47c5a962e51", null ],
      [ "axis", "classCGAL_1_1Shape__detection_1_1Cylinder.html#ab70ecc08bf20f1557135140c6a8b27cd", null ],
      [ "radius", "classCGAL_1_1Shape__detection_1_1Cylinder.html#a882382960df4b853e5f7437e35e4fea1", null ]
    ] ],
    [ "Plane", "classCGAL_1_1Shape__detection_1_1Plane.html", [
      [ "Plane_3", "classCGAL_1_1Shape__detection_1_1Plane.html#a339d71963bfaba40ccf4ec5c4ac23ddc", null ],
      [ "Plane", "classCGAL_1_1Shape__detection_1_1Plane.html#a25b75e71c984e24bd530ed2ab9d03706", null ],
      [ "d", "classCGAL_1_1Shape__detection_1_1Plane.html#a25d40f149a3f1d1a250e63176a6706e9", null ],
      [ "operator Plane_3", "classCGAL_1_1Shape__detection_1_1Plane.html#a4cd87dd8b195fad7a166202fbe5254b3", null ],
      [ "plane_normal", "classCGAL_1_1Shape__detection_1_1Plane.html#a86ef152ba59228d4e3cc02247417b337", null ]
    ] ],
    [ "Shape_base", "classCGAL_1_1Shape__detection_1_1Shape__base.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a951b6ff1055dbb841e6795de62ba7317", null ],
      [ "Point_3", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a6ebc83fd591b472714eebfb420b1e4b5", null ],
      [ "Vector_3", "classCGAL_1_1Shape__detection_1_1Shape__base.html#ac3191429dc84ca1d4dd2385f77242d7e", null ],
      [ "Shape_base", "classCGAL_1_1Shape__detection_1_1Shape__base.html#ae59d77f8af2e00e2ed99a301c67e693d", null ],
      [ "~Shape_base", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a1c6bd3ac67a56b1c4b1913fa302d0539", null ],
      [ "connected_component", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a48186a53453c9a0c11cfebc8dcd399eb", null ],
      [ "connected_component_kdTree", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a5f4db26dacafe017f1cb1b79c456e6be", null ],
      [ "cos_to_normal", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a07f487f782693af3fa42a29f9ad14a97", null ],
      [ "create_shape", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a4f4e29f440b04dccebd9597f98bb3b2e", null ],
      [ "indices_of_assigned_points", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a1928f27b61a84597168790cbc7bbf876", null ],
      [ "info", "classCGAL_1_1Shape__detection_1_1Shape__base.html#ac1bbd0a749fbc118fe266039fcb88b09", null ],
      [ "minimum_sample_size", "classCGAL_1_1Shape__detection_1_1Shape__base.html#afba75428e79da4371347314858440a41", null ],
      [ "normal", "classCGAL_1_1Shape__detection_1_1Shape__base.html#afa97971c02d019424edf02f87911c542", null ],
      [ "point", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a541fb82f5936525b01dc690ae3317fa4", null ],
      [ "squared_distance", "classCGAL_1_1Shape__detection_1_1Shape__base.html#ab04f03619adb9bee6112f074ba2508ff", null ],
      [ "squared_distance", "classCGAL_1_1Shape__detection_1_1Shape__base.html#acd85efee7ba4de1539c379cc0aef7aed", null ],
      [ "traits", "classCGAL_1_1Shape__detection_1_1Shape__base.html#afcb51c89d9098dbb2865515e5823d0f9", null ]
    ] ],
    [ "Sphere", "classCGAL_1_1Shape__detection_1_1Sphere.html", [
      [ "Sphere", "classCGAL_1_1Shape__detection_1_1Sphere.html#ad661a67b3e7fecb678c25a95e4d60650", null ],
      [ "center", "classCGAL_1_1Shape__detection_1_1Sphere.html#ace87742defc26cd4ef3532996cdd3cab", null ],
      [ "operator Sphere_3", "classCGAL_1_1Shape__detection_1_1Sphere.html#a81c0f27fc50fc1319a23751e545e73d1", null ],
      [ "radius", "classCGAL_1_1Shape__detection_1_1Sphere.html#a8035a21c948b464d94b7a37fd3e93085", null ]
    ] ],
    [ "Torus", "classCGAL_1_1Shape__detection_1_1Torus.html", [
      [ "Torus", "classCGAL_1_1Shape__detection_1_1Torus.html#a6530f064d91a60b8e2e43baa25730f69", null ],
      [ "axis", "classCGAL_1_1Shape__detection_1_1Torus.html#a57eabf2a7eadf33d469ebcb0e4267f93", null ],
      [ "center", "classCGAL_1_1Shape__detection_1_1Torus.html#a67f2ccbd1d0b26891e96767108c5fea7", null ],
      [ "major_radius", "classCGAL_1_1Shape__detection_1_1Torus.html#aba00d4c9fbde087c502c7dd62890d4da", null ],
      [ "minor_radius", "classCGAL_1_1Shape__detection_1_1Torus.html#a842d29a31fbab83a13e883f3b0980335", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Shape_detection/group__PkgShapeDetectionRANSACShapes.js <==
var group__PkgShapeDetectionRANSACShapes =
[
    [ "CGAL::Shape_detection::Cone< Traits >", "classCGAL_1_1Shape__detection_1_1Cone.html", [
      [ "angle", "classCGAL_1_1Shape__detection_1_1Cone.html#a91e85e725e1f29a25124a79bfe832006", null ],
      [ "apex", "classCGAL_1_1Shape__detection_1_1Cone.html#ae3a791836bfb4045ff156bd528c288fa", null ],
      [ "axis", "classCGAL_1_1Shape__detection_1_1Cone.html#ada8393051c8779eb9360007c6e69ad55", null ]
    ] ],
    [ "CGAL::Shape_detection::Cylinder< Traits >", "classCGAL_1_1Shape__detection_1_1Cylinder.html", [
      [ "Line_3", "classCGAL_1_1Shape__detection_1_1Cylinder.html#a5ec92e1e403f53f2ff78618b73a5698d", null ],
      [ "axis", "classCGAL_1_1Shape__detection_1_1Cylinder.html#ab70ecc08bf20f1557135140c6a8b27cd", null ],
      [ "radius", "classCGAL_1_1Shape__detection_1_1Cylinder.html#a882382960df4b853e5f7437e35e4fea1", null ]
    ] ],
    [ "CGAL::Shape_detection::Plane< Traits >", "classCGAL_1_1Shape__detection_1_1Plane.html", [
      [ "Plane_3", "classCGAL_1_1Shape__detection_1_1Plane.html#a339d71963bfaba40ccf4ec5c4ac23ddc", null ],
      [ "d", "classCGAL_1_1Shape__detection_1_1Plane.html#a25d40f149a3f1d1a250e63176a6706e9", null ],
      [ "operator Plane_3", "classCGAL_1_1Shape__detection_1_1Plane.html#a4cd87dd8b195fad7a166202fbe5254b3", null ],
      [ "plane_normal", "classCGAL_1_1Shape__detection_1_1Plane.html#a86ef152ba59228d4e3cc02247417b337", null ]
    ] ],
    [ "CGAL::Shape_detection::Shape_base< Traits >", "classCGAL_1_1Shape__detection_1_1Shape__base.html", [
      [ "FT", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a951b6ff1055dbb841e6795de62ba7317", null ],
      [ "Point_3", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a6ebc83fd591b472714eebfb420b1e4b5", null ],
      [ "Vector_3", "classCGAL_1_1Shape__detection_1_1Shape__base.html#ac3191429dc84ca1d4dd2385f77242d7e", null ],
      [ "connected_component", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a48186a53453c9a0c11cfebc8dcd399eb", null ],
      [ "connected_component_kdTree", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a5f4db26dacafe017f1cb1b79c456e6be", null ],
      [ "cos_to_normal", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a07f487f782693af3fa42a29f9ad14a97", null ],
      [ "create_shape", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a4f4e29f440b04dccebd9597f98bb3b2e", null ],
      [ "indices_of_assigned_points", "classCGAL_1_1Shape__detection_1_1Shape__base.html#ad8e6fa8c2ace2bf8835abdccacb50782", null ],
      [ "info", "classCGAL_1_1Shape__detection_1_1Shape__base.html#ac1bbd0a749fbc118fe266039fcb88b09", null ],
      [ "minimum_sample_size", "classCGAL_1_1Shape__detection_1_1Shape__base.html#afba75428e79da4371347314858440a41", null ],
      [ "normal", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a0e27838859722e7cf42bdce04942b53d", null ],
      [ "point", "classCGAL_1_1Shape__detection_1_1Shape__base.html#a06b467e120347afe63016a0cc951b370", null ],
      [ "squared_distance", "classCGAL_1_1Shape__detection_1_1Shape__base.html#ab04f03619adb9bee6112f074ba2508ff", null ],
      [ "squared_distance", "classCGAL_1_1Shape__detection_1_1Shape__base.html#acd85efee7ba4de1539c379cc0aef7aed", null ],
      [ "traits", "classCGAL_1_1Shape__detection_1_1Shape__base.html#ad90f27aef6585a6e5c67aa01bf11feee", null ]
    ] ],
    [ "CGAL::Shape_detection::Sphere< Traits >", "classCGAL_1_1Shape__detection_1_1Sphere.html", [
      [ "center", "classCGAL_1_1Shape__detection_1_1Sphere.html#ace87742defc26cd4ef3532996cdd3cab", null ],
      [ "operator Sphere_3", "classCGAL_1_1Shape__detection_1_1Sphere.html#a81c0f27fc50fc1319a23751e545e73d1", null ],
      [ "radius", "classCGAL_1_1Shape__detection_1_1Sphere.html#a8035a21c948b464d94b7a37fd3e93085", null ]
    ] ],
    [ "CGAL::Shape_detection::Torus< Traits >", "classCGAL_1_1Shape__detection_1_1Torus.html", [
      [ "axis", "classCGAL_1_1Shape__detection_1_1Torus.html#a57eabf2a7eadf33d469ebcb0e4267f93", null ],
      [ "center", "classCGAL_1_1Shape__detection_1_1Torus.html#a67f2ccbd1d0b26891e96767108c5fea7", null ],
      [ "major_radius", "classCGAL_1_1Shape__detection_1_1Torus.html#aba00d4c9fbde087c502c7dd62890d4da", null ],
      [ "minor_radius", "classCGAL_1_1Shape__detection_1_1Torus.html#a842d29a31fbab83a13e883f3b0980335", null ]
    ] ]
];
